summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/uml.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/uml.h')
-rw-r--r--umbrello/umbrello/uml.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/umbrello/umbrello/uml.h b/umbrello/umbrello/uml.h
index 2c4f59c8..dc4dcfec 100644
--- a/umbrello/umbrello/uml.h
+++ b/umbrello/umbrello/uml.h
@@ -69,7 +69,7 @@ class TQCustomEvent;
* full session management as well as using KActions.
* @see KMainWindow
* @see TDEApplication
- * @see KConfig
+ * @see TDEConfig
*
* @author Paul Hensgen <phensgen@techie.com>
* Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
@@ -402,7 +402,7 @@ protected:
* temporary filename provided by TDEApplication.
* @see KMainWindow#saveProperties
*/
- virtual void saveProperties(KConfig *_cfg);
+ virtual void saveProperties(TDEConfig *_cfg);
/**
* Reads the session config file and restores the
@@ -411,7 +411,7 @@ protected:
* saveProperties()
* @see KMainWindow#readProperties
*/
- virtual void readProperties(KConfig *_cfg);
+ virtual void readProperties(TDEConfig *_cfg);
CodeGenerationPolicy * m_commoncodegenpolicy;
@@ -433,7 +433,7 @@ protected slots:
public slots:
/**
* Reads the activeLanguage from the KConfig and calls updateLangSelectMenu()
*/
void initGenerator();
@@ -650,8 +650,8 @@ public slots:
TQString activeLanguageScopeSeparator();
/**
* Return the default code generation language as configured by KConfig.
* If the activeLanguage is not found in the KConfig then use Uml::pl_Cpp
* as the default.
*/
Uml::Programming_Language getDefaultLanguage();
@@ -801,7 +801,7 @@ public slots:
*/
void slotMoveTabRight();
- KConfig *getConfig() { return m_config; }
+ TDEConfig *getConfig() { return m_config; }
/**
* This slot deletes the current XHTML documentation generator as soon as
@@ -866,7 +866,7 @@ private:
/**
* The configuration object of the application.
*/
- KConfig* m_config;
+ TDEConfig* m_config;
/**
* View is the main widget which represents your working area.
@@ -433,7 +433,7 @@ protected slots:
public slots:
/**
- * Reads the activeLanguage from the KConfig and calls updateLangSelectMenu()
+ * Reads the activeLanguage from the TDEConfig and calls updateLangSelectMenu()
*/
void initGenerator();
@@ -650,8 +650,8 @@ public slots:
TQString activeLanguageScopeSeparator();
/**
- * Return the default code generation language as configured by KConfig.
- * If the activeLanguage is not found in the KConfig then use Uml::pl_Cpp
+ * Return the default code generation language as configured by TDEConfig.
+ * If the activeLanguage is not found in the TDEConfig then use Uml::pl_Cpp
* as the default.
*/